@@ -342,6 +342,8 @@
 ( cd opt/kde/share/doc/HTML/es/kicker-applets ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/konq-plugins ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/konq-plugins ; ln -sf /opt/kde/share/doc/HTML/es/common common )
+( cd opt/kde/share/doc/HTML/es/kbabel ; rm -rf common )
+( cd opt/kde/share/doc/HTML/es/kbabel ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kalarm ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kalarm ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kamera ; rm -rf common )
@@ -396,6 +398,8 @@
 ( cd opt/kde/share/doc/HTML/es/kblackbox ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kcharselect ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kcharselect ; ln -sf /opt/kde/share/doc/HTML/es/common common )
+( cd opt/kde/share/doc/HTML/es/quanta ; rm -rf common )
+( cd opt/kde/share/doc/HTML/es/quanta ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kuickshow ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kuickshow ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kiconedit ; rm -rf common )
